@@ -17,7 +17,7 @@ use JSON qw/decode_json/;
 use WWW::Mechanize;
 use Path::Tiny;
 
-our $VERSION = version->new('0.7.0');
+our $VERSION = version->new('0.7.1');
 
 extends 'Group::Git';
 
@@ -26,9 +26,34 @@ has '+recurse' => (
 );
 has 'mech' => (
     is      => 'rw',
-    default => sub { WWW::Mechanize->new; },
+    lazy    => 1,
+    builder => '_mech',
 );
 
+sub _mech {
+    my ($self) = @_;
+    my $mech;
+
+    if ( ! -d $self->conf->{cache_dir} ) {
+        mkdir $self->conf->{cache_dir};
+    }
+
+    if ($self->conf->{cache_dir} && eval { require WWW::Mechanize::Cached; require CHI }) {
+        $mech = WWW::Mechanize::Cached->new(
+            cache => CHI->new(
+                driver     => 'File',
+                root_dir   => $self->conf->{cache_dir},
+                expires_in => '30 min',
+            ),
+        );
+    }
+    else {
+        $mech  = WWW::Mechanize->new;
+    }
+
+    return $mech;
+}
+
 sub _httpenc {
     my ($str) = @_;
     $str =~ s/(\W)/sprintf "%%%x", ord $1/egxms;
@@ -102,7 +127,7 @@ Group::Git::Stash - Adds reading all repositories you have access to on your loc
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Stash version 0.7.0.
+This documentation refers to Group::Git::Stash version 0.7.1.
 
 =head1 SYNOPSIS
 
